# miney - The python interface to minetest

Miney connects to the apisocket mod on a minetest server over network or internet.

## Status: Beta - Prepairing first official release

The sourcecode is online for contribution and external services like appveyor.

## Requirement

* Python 3.6+ (tested on 3.7)
* A minetest-server with [mineysocket](https://github.com/Administerium/mineysocket) mod

## Todos

- [ ] Documentation: Installation instructions for different OS
- [ ] Documentation: Preparations for first run
- [ ] Minetest: Precompiled minetest distribution bundled with luasocket and cjson for windows
